Struct rin::blender::ActionMix[−][src]

pub struct ActionMix<A1, A2> { /* fields omitted */ }

Mixes two different actions by applying the two at the same time

Usually only useful for actions that apply to different elements.

Implementations

impl<A1, A2> ActionMix<A1, A2> where
    A1: ActionExt,
    A2: ActionExt, 
[src]

pub fn new(action1: A1, action2: A2) -> ActionMix<A1, A2>[src]